# - Config file for the Dakota package
# It defines the following variables
#  Dakota_INCLUDE_DIRS - include directories for Dakota
#  Dakota_LIBRARIES    - libraries to link against
#  Dakota_EXECUTABLE   - the dakota executable

# Compute paths
get_filename_component(DAKOTA_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

# Check existence since may be building/installing under
# Trilinos/TriKota, or using an external Trilinos
if (EXISTS "${CMAKE_CURRENT_LIST_DIR}/../Teuchos/TeuchosConfig.cmake")
  include("${CMAKE_CURRENT_LIST_DIR}/../Teuchos/TeuchosConfig.cmake")
endif()

# Conservative approach for now
if (EXISTS "${CMAKE_CURRENT_LIST_DIR}/../../../share/eigen3/cmake")
  set(Eigen3_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../share/eigen3/cmake")
endif()
include(CMakeFindDependencyMacro)
find_dependency(Eigen3)

# Our library dependencies (contains definitions for IMPORTED targets)
include("${DAKOTA_CMAKE_DIR}/DakotaTargets.cmake")


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was DakotaConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# Build tree option not yet working
if (Dakota_BUILD_TREE)
  # Dakota's build tree doesn't have a single convenient place for headers
  set(Dakota_INCLUDE_DIRS_TMP "/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/generated/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/trilinos;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/teuchos/remainder/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/remainder/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/core/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/teuchos/core/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/teuchos/numerics/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/teuchos/comm/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/teuchos/parameterlist/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/teuchos/parser/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/pecos;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/pecos/util/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/pecos/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/VPISparseGrid/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/surfpack;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/surfpack/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/src/util;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/src/surrogates;/usr/include/eigen3;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/acro/packages;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/acro/packages/utilib;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/acro/packages/interfaces/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/acro/packages/scolib/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/acro/packages/utilib/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/acro/packages/colin/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/acro/packages/pebbl/src/bb;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/acro/packages/pebbl/src/comm;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/acro/packages/pebbl/src/misc;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/acro/packages/pebbl/src/pbb;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/acro/packages/pebbl/src/sched;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/acro/tpl/tinyxml;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/approxnn/include;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/DDACE;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/DDACE/include;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/dream;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/FSUDace;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/FSUDace;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/hopspack/src/src-shared;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/hopspack/src/src-shared;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/hopspack/src/src-citizens;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/hopspack/src/src-evaluator;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/hopspack/src/src-executor;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/hopspack/src/src-framework;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/hopspack/src/src-main;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/JEGA;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/JEGA/eddy;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/JEGA/eddy;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/JEGA/include;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/NOMAD/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/NOMAD/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/OPTPP/include;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/OPTPP/include;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/trilinos;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/trilinos/packages/rol/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/rcp;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/parameterlist;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/stacktrace;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/la;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/lapack;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/compatibility/teuchos/blas;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/vector;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/function;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/dynamic;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/boundconstraint;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/constraint;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/nlls;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/objective;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/operator;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/simopt;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/sketching;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/function/std;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/step;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/linesearch;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/trustregion;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/secant;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/krylov;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/bundle;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/augmentedlagrangian;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/moreauyosidapenalty;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/interiorpoint;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/nonlinearcg;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/step/fletcher;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/algorithm;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/status;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/distribution;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/expectationquad;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/risk;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/risk/fdivergence;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/risk/spectral;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/error;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/regret;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/deviation;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/randvarfunctional/probability;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/function/progressivehedging;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/algorithm;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/algorithm/PrimalDual;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/vector;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/sampler;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/sampler/SROM;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/sol/status;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/elementwise;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/utils;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/utils/function_bindings;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/zoo;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/rol/src/zoo/testproblems;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/teuchos/remainder/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/remainder/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/core/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/teuchos/core/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/teuchos/numerics/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/teuchos/comm/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/teuchos/parameterlist/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/trilinos/packages/teuchos/parser/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/packages/external/PSUADE;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/ampl")
  # This won't work yet.  Since Dakota is in a build tree the
  # libraries are scattered, but the import doesn't know where they
  # are.
  set(Dakota_LIBRARY_DIRS_TMP "/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/remainder/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/core/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/numerics/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/comm/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/parameterlist/src;/usr/src/slapt-src/academic/dakota/dakota-6.15.0-public-src-cli/build/packages/external/trilinos/packages/teuchos/parser/src")
else()
  set_and_check(Dakota_INCLUDE_DIRS_TMP "${PACKAGE_PREFIX_DIR}/include")
  set_and_check(Dakota_LIB_DIRS_TMP "${PACKAGE_PREFIX_DIR}/lib")
endif()

# Variables intended for use by other projects

set_and_check(Dakota_DIR ${DAKOTA_CMAKE_DIR})

# TODO: reference in src vs bin
set(Dakota_EXECUTABLE dakota)


set(Dakota_DEFINES "HAVE_CONFIG_H;HAVE_DAKOTA_SURROGATES;HAVE_CONFIG_H;DISABLE_DAKOTA_CONFIG_H;BOOST_DISABLE_ASSERTS;HAVE_UNISTD_H;HAVE_SYSTEM;HAVE_WORKING_FORK;HAVE_WORKING_VFORK;HAVE_SYS_WAIT_H;HAVE_;HAVE_SURFPACK;HAVE_DAKOTA_SURROGATES;DAKOTA_F90;HAVE_ACRO;DAKOTA_UTILIB;HAVE_APPROXNN;HAVE_ADAPTIVE_SAMPLING;HAVE_CONMIN;HAVE_DDACE;HAVE_DREAM;HAVE_FSUDACE;DAKOTA_HOPS;HAVE_JEGA;HAVE_NCSU;HAVE_NL2SOL;HAVE_NOMAD;HAVE_OPTPP;DAKOTA_OPTPP;HAVE_ROL;HAVE_PSUADE;HAVE_AMPL")

set(Dakota_INCLUDE_DIRS ${Dakota_INCLUDE_DIRS_TMP})

set(Dakota_LIBRARY_DIRS ${Dakota_LIB_DIRS_TMP})

# These are IMPORTED targets created by DakotaTargets.cmake
set(Dakota_LIBRARIES "dakota_surrogates;dakota_util;dakota_src;dakota_src_fortran;nidr;teuchosremainder;teuchosnumerics;teuchoscomm;teuchosparameterlist;teuchosparser;teuchoscore;pecos_util;pecos_src;lhs;lhs_mods;lhs_mod;dfftpack;sparsegrid;surfpack;surfpack;surfpack_fortran;utilib;colin;interfaces;scolib;3po;pebbl;tinyxml;approxnn;conmin;ddace;dream;fsudace;hopspack;jega;jega_fe;moga;soga;eutils;utilities;ncsuopt;cport;nomad;optpp;psuade;amplsolver")

# Not built in Dakota's CMake process
set(Dakota_EXTPROJ_LIBRARIES "")

# TPLs external to the build
set(Dakota_TPL_INCLUDE_DIRS "")

set(Dakota_TPL_LIBRARY_DIRS "")

set(Dakota_TPL_LIBRARIES "/usr/lib64/liblapack.so;/usr/lib64/libblas.so")
