# Summary

This is a "start from scratch" example for building both an analysis driver and a Dakota study around a black-box simulation model.  You are encouraged to use the Dakota GUI in conjunction with this example.

# Description

The black-box simulation model used in this example is a *cantilever beam*, which can be thought of as a rigid structural element that extends horizontally and is supported at only one end.

The simulation model accepts seven input parameters:

 - the length of the beam, **L**
 - the width of the beam, **w**
 - the thickness of the beam, **t**
 - Young's modulus, **E**
 - the density of the beam, **p**
 - the horizontal load on the beam, **X**
 - the vertical load on the beam, **Y**

The simulation model produces three output responses:

 - the **mass** of the beam
 - the **stress** on the beam
 - the **displacement** of the beam

This problem is emblematic of most Dakota studies, in that we have a simulation model that takes input parameters and produces output responses, and we would like to use Dakota to study that model.

# Contents

- `cantilever` - the black-box simulation model representing the cantilever beam.  In reality, this is a Python script with the extension removed, so it would be invoked from the command-line as `python cantilever <input file>`, where <input file\> is the input data file for the simulation.
- `cantilever.template` - the templatized input file for the cantilever beam.  Note the presence of curly braces in the text of this file.  This file is primarily used in the **pre-processing** step of analysis driver logic.
- `CantileverBeam.bmf` - a lightweight model definition for the cantilever beam.  This BMF model contains seven input parameters and three output responses.  BMF stands for "basic model format", and these files are generated/used in Dakota GUI.
- `externalProcess.log` - an example output log produced by running the cantilever black-box simulation.  This file could be generated by piping the standard output stream from `python cantilever <input file>` to a log file (for example:  `python cantilever <input file> > externalProcess.log`).  The information captured in this log is primarily used in the **post-processing** step of analysis driver logic.

# How to run the example

You are encouraged to use the Dakota GUI in conjunction with this example.

The Dakota GUI provides **two distinct routes** for building a study around a black-box simulation model.  Which route you choose comes down to your use case / preferred method of working with analysis drivers and Dakota studies.

## Use a generated Python script as the driver

The Dakota GUI has the ability to auto-generate Python driver scripts based on information about your simulation model.

 - **Step 1.** [Read the strategy overview.](https://dakota.sandia.gov/content/connecting-dakota-external-simulation-models-1)
 - **Step 2.** [Learn about BMF files, which are parameterized representations of your simulation models.](https://dakota.sandia.gov/content/bmf-1)
 - **Step 3.** [Create a driver script to wrap the parameterized simulation model.](https://dakota.sandia.gov/content/wizards-1#script-based-dakota-driver-wizard)
 - **Step 4.** [Create a new Dakota study using the Dakota Study Wizard, providing your driver script as the analysis driver.](https://dakota.sandia.gov/content/wizards-1#dakota-study-wizard)

If you would like to see a completed example of this approach, refer to the example located at:

`dakota-examples/official/gui/analysis_driver_tutorial/complete_python_driver`

## Use Next-Gen Workflow to build a visual workflow for your driver

 - **Step 1.** [Read the strategy overview.](https://dakota.sandia.gov/content/connecting-dakota-external-simulation-models-1)
 - **Step 2.** [Learn about BMF files, which are parameterized representations of your simulation models.](https://dakota.sandia.gov/content/bmf-1)
 - **Step 3.** [Create an empty driver workflow using the Workflow-Based Dakota Driver wizard.](https://dakota.sandia.gov/content/wizards-1#workflow-based-dakota-driver)
 - **Step 4.** [Design a workflow that will execute your simulation model.](https://dakota.sandia.gov/content/next-gen-workflow-1#nested-workflow-tutorial)
 - **Step 5.** [Create a new Dakota study using the Dakota Study Wizard, providing your workflow as the analysis driver.](https://dakota.sandia.gov/content/wizards-1#dakota-study-wizard)
 - **Step 6.** [Create an outer wrapper workflow that will run Dakota.](https://dakota.sandia.gov/content/wizards-1#dakota-wrapper-workflow-wizard)

If you would like to see a completed example of this approach, refer to the example located at:

`dakota-examples/official/gui/analysis_driver_tutorial/complete_ngw_driver`